package
Version:
v0.0.0-...-950b7a2
Opens a new window with list of versions in this module.
Published: Apr 19, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type AtomFeed struct {
XMLName xml.Name `xml:"feed"`
Title string `xml:"title"`
Links []AtomLink `xml:"link"`
Updated string `xml:"updated"`
Entries []Entry `xml:"entry"`
}
type AtomLink struct {
Rel string `xml:"rel,attr"`
Href string `xml:"href,attr"`
}
type Channel struct {
Title string `xml:"title"`
Link string `xml:"link"`
PubDate string `xml:"pubDate"`
Items []RssItem `xml:"item"`
}
type Entry struct {
Title string `xml:"title"`
Content string `xml:"content"`
Summary string `xml:"summary"`
Links []AtomLink `xml:"link"`
Updated string `xml:"updated"`
}
type Root struct {
XMLName xml.Name
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.